@@ -6,10 +6,12 @@ use 5.020;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 Travel::Status::DE::DBRIS::JourneyAtStop->mk_ro_accessors(
-	qw(type dep sched_dep rt_dep delay is_cancelled line stop_eva id platform rt_platform destination via via_last)
+	qw(type dep sched_dep rt_dep delay is_cancelled line stop_eva id platform rt_platform destination via via_last
+	  train_short train_mid train_long train maybe_train_no maybe_line_no
+	)
 );
 
 sub new {
@@ -21,6 +23,10 @@ sub new {
 	my $ref = {
 		type        => $json->{verkehrmittel}{kurzText},
 		line        => $json->{verkehrmittel}{mittelText},
+		train       => $json->{verkehrmittel}{name},
+		train_short => $json->{verkehrmittel}{kurzText},
+		train_mid   => $json->{verkehrmittel}{mittelText},
+		train_long  => $json->{verkehrmittel}{langText},
 		id          => $json->{journeyId},
 		stop_eva    => $json->{bahnhofsId},
 		destination => $json->{terminus},
@@ -30,6 +36,9 @@ sub new {
 		via_last    => ( $json->{ueber} // [] )->[-1],
 	};
 
+	$ref->{maybe_train_no} = $ref->{train}     =~ s{^.* ++}{}r;
+	$ref->{maybe_line_no}  = $ref->{train_mid} =~ s{^.* ++}{}r;
+
 	bless( $ref, $obj );
 
 	if ( $json->{zeit} ) {
@@ -66,6 +75,12 @@ sub TO_JSON {
 
 	my $ret = { %{$self} };
 
+	for my $k (qw(sched_dep rt_dep dep sched_arr rt_arr arr)) {
+		if ( $ret->{$k} ) {
+			$ret->{$k} = $ret->{$k}->epoch;
+		}
+	}
+
 	return $ret;
 }
 
